<?php
namespace Fiscal\Util;

use \Fiscal\Entities\Paramfiscal;
use \Geral\Entities\Paramestoque;
use \Geral\Entities\Paramfilial;
use \Geral\Entities\Paramgeral;
use \Geral\Entities\Parasupri;
use \Geral\Entities\Paramempresa;
use \Geral\Util\Ambiente;

class Parametros
{
//    /** @var Paramestoque */
    protected $paramEstoque;
//    /** @var Parasupri */
//    protected $paramSupri;
    /** @var Paramfiscal */
    protected $paramFiscal;
    /** @var $paramFilial Paramfilial*/
    protected $paramFilial;
    /** @var Paramgeral */
    protected $paramGeral;
    /** @var Paramempresa */
    protected $paramEmpresa;

    /** @var Parametros */
    private static $instancia = null;

    protected function __construct() {
        $nrorg = Ambiente::getNrorg();
        $cdempresa = Ambiente::getCdEmpresa();
        $cdfilial = Ambiente::getCdFilial();
//        $this->paramSupri = Parasupri::getObjectByWhere("NRORG = ? AND CDFILIAL = ?", $params);
        $this->paramGeral = Paramgeral::getObjectByWhere("NRORG = ?", array($nrorg));
        $this->paramFilial = Paramfilial::getObjectByWhere("NRORG = ? AND CDFILIAL = ?", array($nrorg, $cdfilial));
        $this->paramFiscal = Paramfiscal::getObjectByWhere("NRORG = ?", array($nrorg));
        $this->paramEstoque = Paramestoque::getObjectByWhere("NRORG = ?", array($nrorg));
        $this->paramEmpresa = Paramempresa::getObjectByWhere("NRORG = ? AND CDEMPRESA = ?", array($nrorg, $cdempresa));
    }

    /**
     * @return \Geral\Entities\Paramempresa
     */
    public function getParamEmpresa()
    {
        return $this->paramEmpresa;
    }

    /**
     * @return \Geral\Entities\Paramfilial
     */
    public function getParamFilial()
    {
        return $this->paramFilial;
    }

    /**
     * @return \Fiscal\Entities\Paramfiscal
     */
    public function getParamFiscal()
    {
        return $this->paramFiscal;
    }

    /**
     * @return \Geral\Entities\Paramgeral
     */
    public function getParamGeral()
    {
        return $this->paramGeral;
    }

    /**
     * @return \Estoque\Util\Parametros;
     */
    public function getParamEstoque()
    {
        return $this->paramEstoque;
    }

    public static function getInstancia() {
        if(self::$instancia === null) {
            self::$instancia = new self();
        }

        return self::$instancia;
    }

    public static function getNumeroLote() {
        return self::getInstancia()->paramFilial->getDsnumelote();
    }

    public static function getParametrosFiscais() {
        return self::getInstancia()->paramGeral->getDspargerfis();

    }

//    public static function getBloqueioFornecedorIrregular() {
//        return self::getInstancia()->paramEstoque->getIdbloqforirr();
//    }

    public static function getPermissaoFornedorParaComprasCotacoes() {
        return self::getInstancia()->paramFilial->getIdperforneco();
    }

//    public static function getUltilizaDtValidadeQualificacoes() {
//        return self::getInstancia()->paramSupri->getIdultidtvalq();
//    }

    public static function getUtilizaAlmoxarifado() {
        return self::getInstancia()->paramFilial->getIdutilalmox();
    }

    public static function getUtilizaIntegracaoNotaFiscalPorFilial() {
        return self::getInstancia()->paramFilial->getIdutilintnff();
    }

    public static function getUtilizaIntegracaoNotaFiscal() {
        return self::getInstancia()->paramGeral->getIdutilintnfg();
    }

    public static function getUtilizaLocalizacaoEstoque() {
        return self::getInstancia()->paramFilial->getIdutillcestq();
    }

    public static function getUtilizaControleEstoquePorLote() {
        return self::getInstancia()->paramFilial->getIdutillote();
    }


    public static function getIdutctrlfis() {
        return self::getInstancia()->paramFilial->getIdutctrlfis();
    }

    public static function getUtilizaNotaFiscalEletronica() {
        return self::getInstancia()->paramEmpresa->getIdemputilizanfe();
    }

    public static function getUtilizaDataProcNFE() {
        return self::getInstancia()->paramGeral->getIdutdtproctnfe();
    }

    public static function getSituacaoCRT()
    {
        return self::getInstancia()->paramEmpresa->getCdsitucrt();
    }

    public static function getUtilizaFilialCentralizadora() {
        return self::getInstancia()->paramGeral->getIdutfilcentobr();
    }

    public static function getDataProcessamento() {
        if (
            self::getInstancia()->paramGeral->getIdutildtproc() === 'S' &&
            self::getInstancia()->paramFilial->getDtprocessa() !== ''
        ) {
            return self::getInstancia()->paramFilial->getDtprocessa()->format('d/m/Y');
        }

        return date('d/m/Y');
    }

    public static function getNumerosDiasBloqueioDataEmissao() {
        return self::getInstancia()->paramGeral->getNrdiasbloqdtemi();
    }

    public static function getNumerosDiasAvisosDataEmissao() {
        return self::getInstancia()->paramGeral->getNrdiasavisdtemi();
    }
}
