CREATE OR REPLACE PACKAGE SUP_COTACAO AS
   
    K_S                     CONSTANT VARCHAR2(01) := 'S';
    K_N                     CONSTANT VARCHAR2(01) := 'N';
    K_T                     CONSTANT VARCHAR2(01) := 'T';
    K_N1                    CONSTANT NUMBER       := 1;
    K_N0                    CONSTANT NUMBER       := 0;
    K_SUCCESS               CONSTANT VARCHAR2(07) := 'SUCCESS';
    K_ERROR                 CONSTANT VARCHAR2(05) := 'ERROR';
    K_PZOPGTPRFO            CONSTANT VARCHAR2(30) := 'PZOPGTPRFO';
    K_PRAZOPGTFORN          CONSTANT VARCHAR2(30) := 'PRAZOPGTFORN';
    K_COTACAO_CONCLUIDA     CONSTANT VARCHAR2(30) := 'COTACAO_CONCLUIDA_IDCOTCONCLUI';
    K_DSMET_DUPLICA_COTACAO CONSTANT VARCHAR2(30) := 'SUP_COTACAO.DUPLICA_COTACAO';
    K_NRORG                 CONSTANT NUMBER       := NVL(SYS_CONTEXT('nrorg_ctx','nrorg'), 1);

    /*Subtype*/
    SUBTYPE S_RECORD_COLETAPR     IS COLETAPR%ROWTYPE;
    SUBTYPE S_RECORD_ITEMCOLE     IS ITEMCOLE%ROWTYPE;
    SUBTYPE S_RECORD_LOGCOLETAPR  IS LOGCOLETAPR%ROWTYPE;
    SUBTYPE S_RECORD_LOGITEMCOLE  IS LOGITEMCOLE%ROWTYPE;
    SUBTYPE S_RECORD_PZOPGTITMCOL IS PZOPGTITMCOL%ROWTYPE;

    PROCEDURE INSERT_COLETAPR(P_REGISTRO      IN OUT S_RECORD_COLETAPR,
                              P_CDFORNECED    IN FORNECEDOR.CDFORNECED%TYPE,
                              P_PARASUPRI     IN PARASUPRI%ROWTYPE,
                              P_FORNECEDORES OUT FORNECEDOR%ROWTYPE,
                              P_ERROR        OUT VARCHAR2);

    PROCEDURE INSERT_ITEMCOLE(P_REGISTRO     IN OUT S_RECORD_ITEMCOLE,
                              P_PARASUPRI    IN PARASUPRI%ROWTYPE,
                              P_FORNECEDORES IN FORNECEDOR%ROWTYPE,
                              P_ERROR       OUT VARCHAR2);

    PROCEDURE DELETE_PZOPGTITMCOL(P_REGISTRO IN S_RECORD_ITEMCOLE,
                                  P_ERROR   OUT VARCHAR2);

    PROCEDURE INSERT_PZOPGTITMCOL(P_REGISTRO   IN S_RECORD_ITEMCOLE,
                                  P_CDPRODFORN IN PRODFORN.CDPRODUTO%TYPE DEFAULT NULL,
                                  P_ERROR     OUT VARCHAR2);

    PROCEDURE INSERT_LOGCOLETAPR(P_COLETAPR      IN S_RECORD_COLETAPR,
                                 P_DSENDUSULOG   IN LOGCOLETAPR.DSENDUSULOG%TYPE,
                                 P_DSNMUSULOG    IN LOGCOLETAPR.DSNMUSULOG%TYPE,
                                 P_DSRDMUSULOG   IN LOGCOLETAPR.DSRDMUSULOG%TYPE,
                                 P_DSMETUSULOG   IN LOGCOLETAPR.DSMETUSULOG%TYPE,
                                 P_CDOPERINCLOG  IN LOGCOLETAPR.CDOPERINCLOG%TYPE,
                                 P_IDOPERCOTLOG  IN LOGCOLETAPR.IDOPERCOTLOG%TYPE,
                                 P_DSMESSAGERROR IN LOGCOLETAPR.DSMESSAGERROR%TYPE); 

    PROCEDURE INSERT_LOGITEMCOLE(P_ITEMCOLE      IN S_RECORD_ITEMCOLE,
                                 P_DSENDUSULIC   IN LOGITEMCOLE.DSENDUSULIC%TYPE,
                                 P_DSNMUSULIC    IN LOGITEMCOLE.DSNMUSULIC%TYPE,
                                 P_DSRDMUSULIC   IN LOGITEMCOLE.DSRDMUSULIC%TYPE,
                                 P_DSMETUSULIC   IN LOGITEMCOLE.DSMETUSULIC%TYPE,
                                 P_CDOPERLIC     IN LOGITEMCOLE.CDOPERLIC%TYPE,
                                 P_IDOPERALIC    IN LOGITEMCOLE.IDOPERALIC%TYPE,
                                 P_DSMESSAGERROR IN LOGITEMCOLE.DSMESSAGERROR%TYPE);

    PROCEDURE COTACAO_OPL(P_CDFILIAL    IN COLETAPR.CDFILIAL%TYPE,
                          P_NRCOLEORIG  IN COLETAPR.NRCOLEPRECO%TYPE,
                          P_NRCOLEPRECO IN COLETAPR.NRCOLEPRECO%TYPE,
                          P_FORNOL      IN VARCHAR2,
                          P_REAJUSTE    IN NUMBER,
                          P_DTNOVINIVAL IN COLETAPR.DTINIVALCOL%TYPE,
                          P_DTNOVFINVAL IN COLETAPR.DTFINVALCOL%TYPE,
                          P_CDOPERINCL  IN OPERADOR.CDOPERADOR%TYPE);
    
    PROCEDURE DUPLICA_COTACAO(P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
                              P_CDFILIPROC   IN FILIAL.CDFILIAL%TYPE,
                              P_NRCOLEPRECO  IN COLETAPR.NRCOLEPRECO%TYPE,
                              P_NRSEMAINIC   IN COLETAPR.NRSEMAINIC%TYPE,
                              P_NRSEMAFINAL  IN COLETAPR.NRSEMAFINAL%TYPE,
                              P_DTNOVINIVAL  IN COLETAPR.DTINIVALCOL%TYPE,
                              P_DTNOVFINVAL  IN COLETAPR.DTFINVALCOL%TYPE,
                              P_DTINIVALCOL  IN COLETAPR.DTINIVALCOL%TYPE,
                              P_DTFINVALCOL  IN COLETAPR.DTFINVALCOL%TYPE,
                              P_DTCOLEPREC   IN COLETAPR.DTCOLEPREC%TYPE,
                              P_REAJUSTE     IN NUMBER,
                              P_NRCOLEDUP    IN COLETAPR.NRCOLEPRECO%TYPE,
                              P_IDDUPLICA    IN VARCHAR2,
                              P_CDOPERADOR   IN VARCHAR2 DEFAULT NULL,
                              P_TCDOPERADOR  IN VARCHAR2,
                              P_CDOPERINCL   IN VARCHAR2,
                              P_CDREGIAO     IN VARCHAR2 DEFAULT NULL,
                              P_CDFORNOL     IN VARCHAR2 DEFAULT NULL,
                              P_COTA_N_DUP   OUT VARCHAR2);
END SUP_COTACAO;
/

CREATE OR REPLACE PACKAGE BODY SUP_COTACAO AS

    PROCEDURE INSERT_COLETAPR(P_REGISTRO      IN OUT S_RECORD_COLETAPR,
                              P_CDFORNECED    IN FORNECEDOR.CDFORNECED%TYPE,
                              P_PARASUPRI     IN PARASUPRI%ROWTYPE,
                              P_FORNECEDORES OUT FORNECEDOR%ROWTYPE,
                              P_ERROR        OUT VARCHAR2) IS
        C_FORNECEDORES FORNECEDOR%ROWTYPE;                                           
    BEGIN        
        SUP_VALIDATIONS.CHECK_FORNECEDOR(P_CDFORNECED   => P_CDFORNECED,
                                         P_DTPEDIDO     => P_REGISTRO.DTFINVALCOL,
                                         P_PARASUPRI    => P_PARASUPRI,
                                         P_FORNECEDORES => C_FORNECEDORES,
                                         P_MESSAGE      => P_ERROR);
        IF P_ERROR IS NULL THEN   
            
            P_REGISTRO.IDSITUCOLETA := CASE NVL(P_PARASUPRI.IDUTISTATCOT, 'N') WHEN 'S' THEN 'A' ELSE 'C' END;
            P_REGISTRO.DTINCLCOLET  := SYSDATE;  

            SELECT TO_CHAR(TO_DATE(P_REGISTRO.DTINIVALCOL, 'DD/MM/YYYY'),'WW'), 
                   TO_CHAR(TO_DATE(P_REGISTRO.DTFINVALCOL, 'DD/MM/YYYY'),'WW')
              INTO P_REGISTRO.NRSEMAINIC, 
                   P_REGISTRO.NRSEMAFINAL
              FROM DUAL;
            
            BEGIN
                INSERT INTO COLETAPR
                     VALUES P_REGISTRO;
            EXCEPTION
                WHEN OTHERS THEN
                    P_ERROR := SQLERRM;
            END;

            P_FORNECEDORES := NULL;
        ELSE
            P_FORNECEDORES := C_FORNECEDORES;
        END IF;
    END INSERT_COLETAPR;

    PROCEDURE INSERT_ITEMCOLE(P_REGISTRO     IN OUT S_RECORD_ITEMCOLE,
                              P_PARASUPRI    IN PARASUPRI%ROWTYPE,
                              P_FORNECEDORES IN FORNECEDOR%ROWTYPE,
                              P_ERROR       OUT VARCHAR2) IS
        V_PRODFORN PRODFORN%ROWTYPE;
        V_ERROR    VARCHAR2(4000);
    BEGIN
        /*Fornecedor atende regio*/
        V_ERROR := SUP_VALIDATIONS.FORNECEDOR_ATENDE_REGIAO(P_CDFORNECED => P_REGISTRO.CDFORNECED,
                                                            P_CDREGIAO   => P_REGISTRO.CDREGIAO);
        IF V_ERROR IS NULL THEN
            /*Qualificao produto por fornecedor*/
            V_ERROR := SUP_VALIDATIONS.QUALIFICACAO_PROD_FORN(P_CDPRODUTO  => P_REGISTRO.CDPRODUTO,
                                                              P_CDFORNECED => P_REGISTRO.CDFORNECED,
                                                              P_DTPEDIDO   => P_REGISTRO.DTFINVALITM,
                                                              P_PARASUPRI  => P_PARASUPRI);
        END IF;

        IF V_ERROR IS NULL THEN
            /*Qualificao marca por produto*/
            V_ERROR := SUP_VALIDATIONS.QUALIFICACAO_MARCA_PRODUTO(P_CDPRODUTO => P_REGISTRO.CDPRODUTO,
                                                                  P_CDMARCA   => P_REGISTRO.CDMARCA,
                                                                  P_DTPEDIDO  => P_REGISTRO.DTFINVALITM,
                                                                  P_PARASUPRI => P_PARASUPRI);

        END IF;

        IF V_ERROR IS NULL THEN
            /*Produto no cadastrado para o fornecedor*/
            V_ERROR := SUP_VALIDATIONS.CHECK_PRODUTO_FORNECEDOR(P_CDPRODUTO  => P_REGISTRO.CDPRODUTO,
                                                                P_CDFORNECED => P_REGISTRO.CDFORNECED);
        END IF;

        IF V_ERROR IS NULL THEN
            BEGIN
                SELECT *
                  INTO V_PRODFORN
                  FROM PRODFORN
                 WHERE CDFORNECED = P_REGISTRO.CDFORNECED
                   AND EXISTS (SELECT 1
                                 FROM PRODFORN PF
                                 JOIN PRODUTO PI ON PI.CDPRODUTO = PF.CDPRODUTO
                                 JOIN PRODUTO PR ON PR.CDARVPROD LIKE PI.CDARVPROD || '%'
                                WHERE PF.CDFORNECED = PRODFORN.CDFORNECED
                                  AND PI.CDPRODUTO  = PRODFORN.CDPRODUTO
                                  AND PR.CDPRODUTO  = P_REGISTRO.CDPRODUTO);
                
                P_REGISTRO.CDFORMPGTO   := V_PRODFORN.CDFORMPGTO; 
                P_REGISTRO.IDTPFOPGTCOL := V_PRODFORN.IDTPFORPGPRF;
                P_REGISTRO.NRPARCPGTCOL := V_PRODFORN.NRPARCPGTPRF;
                P_REGISTRO.NRDIAPGFXCOL := V_PRODFORN.NRDIAPGFIPRF;
                P_REGISTRO.IDUTDIAPGCOL := V_PRODFORN.IDUTDIAPGPRF;
                
                BEGIN
                    INSERT INTO ITEMCOLE
                        VALUES P_REGISTRO;
                EXCEPTION
                    WHEN OTHERS THEN
                        V_ERROR := SQLERRM;
                END;

                IF V_ERROR IS NULL THEN
                    DELETE_PZOPGTITMCOL(P_REGISTRO => P_REGISTRO,
                                        P_ERROR    => V_ERROR);

                    INSERT_PZOPGTITMCOL(P_REGISTRO   => P_REGISTRO,
                                        P_CDPRODFORN => V_PRODFORN.CDPRODUTO,
                                        P_ERROR      => V_ERROR);
                END IF;
            EXCEPTION
                WHEN NO_DATA_FOUND THEN
                    P_REGISTRO.CDFORMPGTO   := P_FORNECEDORES.CDFORMPGTO; 
                    P_REGISTRO.IDTPFOPGTCOL := P_FORNECEDORES.IDTPFORPGTFO;
                    P_REGISTRO.NRPARCPGTCOL := P_FORNECEDORES.NRPARCPGTOFO;
                    P_REGISTRO.NRDIAPGFXCOL := P_FORNECEDORES.NRDIAPGFIXFO;
                    P_REGISTRO.IDUTDIAPGCOL := P_FORNECEDORES.IDUTDIAPGTFO;

                    BEGIN
                        INSERT INTO ITEMCOLE
                             VALUES P_REGISTRO;
                    EXCEPTION
                        WHEN OTHERS THEN
                            V_ERROR := SQLERRM;
                    END;

                    IF V_ERROR IS NULL THEN
                        DELETE_PZOPGTITMCOL(P_REGISTRO => P_REGISTRO,
                                            P_ERROR    => V_ERROR);

                        INSERT_PZOPGTITMCOL(P_REGISTRO => P_REGISTRO,
                                            P_ERROR    => V_ERROR);
                    END IF;
            END;
        END IF;

        P_ERROR := V_ERROR;
    END INSERT_ITEMCOLE;

    PROCEDURE DELETE_PZOPGTITMCOL(P_REGISTRO IN S_RECORD_ITEMCOLE,
                                  P_ERROR   OUT VARCHAR2) IS
    BEGIN
        DELETE PZOPGTITMCOL
         WHERE NRCOLEPRECO  = P_REGISTRO.NRCOLEPRECO
           AND CDFORNECED   = P_REGISTRO.CDFORNECED
           AND CDFILIAL     = P_REGISTRO.CDFILIAL
           AND CDREGIAO     = P_REGISTRO.CDREGIAO
           AND CDPRODUTO    = P_REGISTRO.CDPRODUTO
           AND CDMARCA      = P_REGISTRO.CDMARCA;
    EXCEPTION
        WHEN OTHERS THEN
            P_ERROR := SQLERRM;
    END DELETE_PZOPGTITMCOL;

    PROCEDURE INSERT_PZOPGTITMCOL(P_REGISTRO   IN S_RECORD_ITEMCOLE,
                                  P_CDPRODFORN IN PRODFORN.CDPRODUTO%TYPE DEFAULT NULL,
                                  P_ERROR     OUT VARCHAR2) IS
        V_RECORD S_RECORD_PZOPGTITMCOL;
    BEGIN
        V_RECORD.CDFILIAL    := P_REGISTRO.CDFILIAL;
        V_RECORD.NRCOLEPRECO := P_REGISTRO.NRCOLEPRECO;
        V_RECORD.CDPRODUTO   := P_REGISTRO.CDPRODUTO;
        V_RECORD.CDMARCA     := P_REGISTRO.CDMARCA;
        V_RECORD.CDREGIAO    := P_REGISTRO.CDREGIAO;
        
        FOR C_PRAZO IN (SELECT CDFORNECED,
                               NRDIASPGPRFO NRDIASPGTCOL,
                               VRPERCPGPRFO VRPERCPGTCOL,
                               NRORG,
                               IDATIVO
                          FROM PZOPGTPRFO
                         WHERE CDPRODUTO  = P_CDPRODFORN
                           AND CDFORNECED = P_REGISTRO.CDFORNECED
                         UNION ALL   
                        SELECT CDFORNECED,
                               NRDIASPGTOFO NRDIASPGTCOL,
                               VRPERCPGTOFO VRPERCPGTCOL,
                               NRORG,
                               IDATIVO
                          FROM PRAZOPGTFORN
                         WHERE CDFORNECED = P_REGISTRO.CDFORNECED
                           AND NOT EXISTS (SELECT 1
                                             FROM PZOPGTPRFO PZ
                                            WHERE PZ.CDPRODUTO    = P_CDPRODFORN
                                              AND PZ.CDFORNECED   = PRAZOPGTFORN.CDFORNECED))
        LOOP
            V_RECORD.CDFORNECED   := C_PRAZO.CDFORNECED; 
            V_RECORD.NRDIASPGTCOL := C_PRAZO.NRDIASPGTCOL;
            V_RECORD.VRPERCPGTCOL := C_PRAZO.VRPERCPGTCOL;
            V_RECORD.NRORG        := C_PRAZO.NRORG;
            V_RECORD.IDATIVO      := C_PRAZO.IDATIVO;

            BEGIN
                INSERT INTO PZOPGTITMCOL
                     VALUES V_RECORD;
            EXCEPTION
                WHEN OTHERS THEN
                    P_ERROR := SQLERRM;
            END;
        END LOOP;
    END INSERT_PZOPGTITMCOL;

    PROCEDURE INSERT_LOGCOLETAPR(P_COLETAPR      IN S_RECORD_COLETAPR,
                                 P_DSENDUSULOG   IN LOGCOLETAPR.DSENDUSULOG%TYPE,
                                 P_DSNMUSULOG    IN LOGCOLETAPR.DSNMUSULOG%TYPE,
                                 P_DSRDMUSULOG   IN LOGCOLETAPR.DSRDMUSULOG%TYPE,
                                 P_DSMETUSULOG   IN LOGCOLETAPR.DSMETUSULOG%TYPE,
                                 P_CDOPERINCLOG  IN LOGCOLETAPR.CDOPERINCLOG%TYPE,
                                 P_IDOPERCOTLOG  IN LOGCOLETAPR.IDOPERCOTLOG%TYPE,
                                 P_DSMESSAGERROR IN LOGCOLETAPR.DSMESSAGERROR%TYPE) IS
        V_REC_LOGCOLETAPR S_RECORD_LOGCOLETAPR;
    BEGIN
        V_REC_LOGCOLETAPR.CDFILIALLOG   := P_COLETAPR.CDFILIAL; 
        V_REC_LOGCOLETAPR.NRCOLEPRLOG   := P_COLETAPR.NRCOLEPRECO; 
        V_REC_LOGCOLETAPR.CDCOMPLOG     := P_COLETAPR.CDOPERADOR; 
        V_REC_LOGCOLETAPR.DTCOLEPRLOG   := P_COLETAPR.DTCOLEPREC; 
        V_REC_LOGCOLETAPR.NRSEMAINLOG   := P_COLETAPR.NRSEMAINIC; 
        V_REC_LOGCOLETAPR.NRSEMAFILOG   := P_COLETAPR.NRSEMAFINAL; 
        V_REC_LOGCOLETAPR.DTINIVALLOG   := P_COLETAPR.DTINIVALCOL; 
        V_REC_LOGCOLETAPR.DTFINVALLOG   := P_COLETAPR.DTFINVALCOL; 
        V_REC_LOGCOLETAPR.CDOPECOLLOG   := P_COLETAPR.CDOPERINCL; 
        V_REC_LOGCOLETAPR.DTULTCOLLOG   := SYSDATE;                 
        V_REC_LOGCOLETAPR.IDOPERCOTLOG  := P_IDOPERCOTLOG; 
        V_REC_LOGCOLETAPR.NRCOLEORILOG  := P_COLETAPR.NRCOLEORIGCO; 
        V_REC_LOGCOLETAPR.DTINCLITMLOG  := SYSDATE;
        V_REC_LOGCOLETAPR.DSMESSAGERROR := P_DSMESSAGERROR;

        V_REC_LOGCOLETAPR.DSENDUSULOG   := P_DSENDUSULOG;
        V_REC_LOGCOLETAPR.DSNMUSULOG    := P_DSNMUSULOG;
        V_REC_LOGCOLETAPR.DSRDMUSULOG   := P_DSRDMUSULOG;
        V_REC_LOGCOLETAPR.DSMETUSULOG   := SUBSTR(K_DSMET_DUPLICA_COTACAO||P_DSMETUSULOG, 0, 250);
        V_REC_LOGCOLETAPR.CDOPERINCLOG  := P_CDOPERINCLOG;
        V_REC_LOGCOLETAPR.NRORG         := K_NRORG;

        INSERT INTO LOGCOLETAPR
             VALUES V_REC_LOGCOLETAPR;

    END INSERT_LOGCOLETAPR;

    PROCEDURE INSERT_LOGITEMCOLE(P_ITEMCOLE      IN S_RECORD_ITEMCOLE,
                                 P_DSENDUSULIC   IN LOGITEMCOLE.DSENDUSULIC%TYPE,
                                 P_DSNMUSULIC    IN LOGITEMCOLE.DSNMUSULIC%TYPE,
                                 P_DSRDMUSULIC   IN LOGITEMCOLE.DSRDMUSULIC%TYPE,
                                 P_DSMETUSULIC   IN LOGITEMCOLE.DSMETUSULIC%TYPE,
                                 P_CDOPERLIC     IN LOGITEMCOLE.CDOPERLIC%TYPE,
                                 P_IDOPERALIC    IN LOGITEMCOLE.IDOPERALIC%TYPE,
                                 P_DSMESSAGERROR IN LOGITEMCOLE.DSMESSAGERROR%TYPE) IS
        V_REC_LOGITEMCOLE S_RECORD_LOGITEMCOLE;
    BEGIN
        V_REC_LOGITEMCOLE.CDFILIALLIC   := P_ITEMCOLE.CDFILIAL; 
        V_REC_LOGITEMCOLE.NRCOLEPRELIC  := P_ITEMCOLE.NRCOLEPRECO; 
        V_REC_LOGITEMCOLE.CDMARCALIC    := P_ITEMCOLE.CDMARCA;
        V_REC_LOGITEMCOLE.CDREGIAOLIC   := P_ITEMCOLE.CDREGIAO;
        V_REC_LOGITEMCOLE.CDFORNECELIC  := P_ITEMCOLE.CDFORNECED;
        V_REC_LOGITEMCOLE.CDPRODUTOLIC  := P_ITEMCOLE.CDPRODUTO;
        V_REC_LOGITEMCOLE.DTINIVALLIC   := P_ITEMCOLE.DTINIVALITM;
        V_REC_LOGITEMCOLE.DTFINVALLIC   := P_ITEMCOLE.DTFINVALITM;
        V_REC_LOGITEMCOLE.DTOPERACLIC   := SYSDATE; 
        V_REC_LOGITEMCOLE.IDOPERALIC    := P_IDOPERALIC;
        V_REC_LOGITEMCOLE.DSRDMUSULIC   := P_DSRDMUSULIC;
        V_REC_LOGITEMCOLE.DSENDUSULIC   := P_DSENDUSULIC;
        V_REC_LOGITEMCOLE.DSNMUSULIC    := P_DSNMUSULIC;
        V_REC_LOGITEMCOLE.DSMETUSULIC   := SUBSTR(K_DSMET_DUPLICA_COTACAO||P_DSMETUSULIC, 0, 250);
        V_REC_LOGITEMCOLE.CDOPERLIC     := P_CDOPERLIC;
        V_REC_LOGITEMCOLE.VRPRECANTLIC  := 0;
        V_REC_LOGITEMCOLE.VRPRECDEPLIC  := P_ITEMCOLE.VRPRECUNIITM;
        V_REC_LOGITEMCOLE.IDITMLISPLIC  := P_ITEMCOLE.IDITMLISPREC;
        V_REC_LOGITEMCOLE.NRCOLEORILIC  := P_ITEMCOLE.NRCOLEORIGIC;
        V_REC_LOGITEMCOLE.DTINCLITMLIC  := SYSDATE;
        V_REC_LOGITEMCOLE.CDOPERINCLIC  := P_ITEMCOLE.CDOPERINCL;
        V_REC_LOGITEMCOLE.VRPRECECOLIC  := P_ITEMCOLE.VRPRECECOITM;
        V_REC_LOGITEMCOLE.VRPRECOPILIC  := P_ITEMCOLE.VRPRECOITMPI;
        V_REC_LOGITEMCOLE.DSMESSAGERROR := P_DSMESSAGERROR;
        V_REC_LOGITEMCOLE.NRORG         := K_NRORG;
        V_REC_LOGITEMCOLE.IDATIVO       := 'S';

        INSERT INTO LOGITEMCOLE
             VALUES V_REC_LOGITEMCOLE;
    
    END INSERT_LOGITEMCOLE;

    PROCEDURE COTACAO_OPL(P_CDFILIAL    IN COLETAPR.CDFILIAL%TYPE,
                          P_NRCOLEORIG  IN COLETAPR.NRCOLEPRECO%TYPE,
                          P_NRCOLEPRECO IN COLETAPR.NRCOLEPRECO%TYPE,
                          P_FORNOL      IN VARCHAR2,
                          P_REAJUSTE    IN NUMBER,
                          P_DTNOVINIVAL IN COLETAPR.DTINIVALCOL%TYPE,
                          P_DTNOVFINVAL IN COLETAPR.DTFINVALCOL%TYPE,
                          P_CDOPERINCL  IN OPERADOR.CDOPERADOR%TYPE) IS
        V_REC_ITEMCOLE S_RECORD_ITEMCOLE;
        C_PARASUPRI    PARASUPRI%ROWTYPE;
        C_FORNECEDORES FORNECEDOR%ROWTYPE;
        V_ERROR        VARCHAR2(4000);
        V_DSIP         VARCHAR2(50);
        V_DSUSUARIO    VARCHAR2(50);
        V_DSRDM        VARCHAR2(50);
        V_DSMETODO     VARCHAR2(250);
        V_DSOPERADOR   VARCHAR2(12);

    BEGIN
        WEBTUNNING(V_DSIP,
                   V_DSUSUARIO,
                   V_DSRDM,
                   V_DSMETODO,
                   V_DSOPERADOR);
        
        SUP_VALIDATIONS.CHECK_PARASUPRI(P_CDFILIAL  => P_CDFILIAL,
                                        P_PARASUPRI => C_PARASUPRI,
                                        P_ERROR     => V_ERROR);
        IF V_ERROR IS NOT NULL THEN
            RETURN;
        END IF;

        FOR C_REGIAO IN (SELECT CDREGIAO, CDFORNOPELOG
                           FROM FILIAL
                          WHERE INSTR(P_FORNOL, CDFORNOPELOG) > 0
                          GROUP BY CDREGIAO, CDFORNOPELOG)
        LOOP                          
            SUP_VALIDATIONS.CHECK_FORNECEDOR(P_CDFORNECED   => C_REGIAO.CDFORNOPELOG,
                                             P_DTPEDIDO     => P_DTNOVFINVAL,
                                             P_PARASUPRI    => C_PARASUPRI,
                                             P_FORNECEDORES => C_FORNECEDORES,
                                             P_MESSAGE      => V_ERROR);
            IF V_ERROR IS NULL THEN
                FOR C_ITENS IN (SELECT ITEMCOLE.CDPRODUTO, RO.CDMARCA, MIN(ITEMCOLE.VRPRECUNIITM) VRPRECUNIITM, 
                                       MIN(ITEMCOLE.VRPRECECOITM) VRPRECECOITM, MIN(ITEMCOLE.VRPERDESITM) VRPERDESITM,
                                       MIN(ITEMCOLE.VRPRECOITMPI) VRPRECOITMPI
                                  FROM ITEMCOLE
                                  JOIN RELACPRODOL RO ON ITEMCOLE.CDPRODUTO = RO.CDPRARVORIG
                                 WHERE ITEMCOLE.CDFILIAL    = P_CDFILIAL
                                   AND ITEMCOLE.NRCOLEPRECO = P_NRCOLEORIG
                                   --AND ITEMCOLE.CDFORNECED  = C_REGIAO.CDFORNOPELOG
                                   AND ITEMCOLE.VRPRECUNIITM > 0
                                 GROUP BY ITEMCOLE.CDPRODUTO, RO.CDMARCA)
                LOOP
                    V_REC_ITEMCOLE.CDFILIAL        := P_CDFILIAL;
                    V_REC_ITEMCOLE.NRCOLEPRECO     := P_NRCOLEPRECO;
                    V_REC_ITEMCOLE.CDREGIAO        := C_REGIAO.CDREGIAO;
                    V_REC_ITEMCOLE.CDFORNECED      := C_REGIAO.CDFORNOPELOG;
                    V_REC_ITEMCOLE.CDPRODUTO       := C_ITENS.CDPRODUTO;
                    V_REC_ITEMCOLE.CDMARCA         := C_ITENS.CDMARCA;
                    
                    V_REC_ITEMCOLE.VRPRECUNIITM    := C_ITENS.VRPRECUNIITM + ((C_ITENS.VRPRECUNIITM * NVL(P_REAJUSTE, 1)) / 100);
                    V_REC_ITEMCOLE.VRPRECECOITM    := C_ITENS.VRPRECECOITM;
                    V_REC_ITEMCOLE.VRPERDESITM     := C_ITENS.VRPERDESITM;
                    V_REC_ITEMCOLE.VRPRECOITMPI    := C_ITENS.VRPRECOITMPI;
                    V_REC_ITEMCOLE.DTINIVALITM     := P_DTNOVINIVAL;
                    V_REC_ITEMCOLE.DTFINVALITM     := P_DTNOVFINVAL;
                    V_REC_ITEMCOLE.NRCOLEORIGIC    := P_NRCOLEORIG;
                    V_REC_ITEMCOLE.CDOPERINCL      := P_CDOPERINCL;
                    V_REC_ITEMCOLE.IDITMLISPREC    := 'N';
                    V_REC_ITEMCOLE.IDPRECALT       := 'N';
                    V_REC_ITEMCOLE.IDITVALDIFLISTA := 'S';
                    V_REC_ITEMCOLE.DTINCLITMCOL    := SYSDATE;

                    INSERT_ITEMCOLE(P_REGISTRO     => V_REC_ITEMCOLE,
                                    P_PARASUPRI    => C_PARASUPRI,
                                    P_FORNECEDORES => C_FORNECEDORES,
                                    P_ERROR        => V_ERROR);

                    IF V_ERROR IS NOT NULL THEN
                        INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                           P_DSENDUSULIC   => V_DSIP,
                                           P_DSNMUSULIC    => V_DSUSUARIO,
                                           P_DSRDMUSULIC   => V_DSRDM,
                                           P_DSMETUSULIC   => V_DSMETODO,
                                           P_CDOPERLIC     => V_DSOPERADOR,
                                           P_IDOPERALIC    => 'I',
                                           P_DSMESSAGERROR => V_ERROR);
                    END IF;
                END LOOP;
            END IF;
        END LOOP;
    END COTACAO_OPL;

    PROCEDURE DUPLICA_COTACAO(P_CDFILIAL     IN FILIAL.CDFILIAL%TYPE,
                              P_CDFILIPROC   IN FILIAL.CDFILIAL%TYPE,
                              P_NRCOLEPRECO  IN COLETAPR.NRCOLEPRECO%TYPE,
                              P_NRSEMAINIC   IN COLETAPR.NRSEMAINIC%TYPE,
                              P_NRSEMAFINAL  IN COLETAPR.NRSEMAFINAL%TYPE,
                              P_DTNOVINIVAL  IN COLETAPR.DTINIVALCOL%TYPE,
                              P_DTNOVFINVAL  IN COLETAPR.DTFINVALCOL%TYPE,
                              P_DTINIVALCOL  IN COLETAPR.DTINIVALCOL%TYPE,
                              P_DTFINVALCOL  IN COLETAPR.DTFINVALCOL%TYPE,
                              P_DTCOLEPREC   IN COLETAPR.DTCOLEPREC%TYPE,
                              P_REAJUSTE     IN NUMBER,
                              P_NRCOLEDUP    IN COLETAPR.NRCOLEPRECO%TYPE,
                              P_IDDUPLICA    IN VARCHAR2,
                              P_CDOPERADOR   IN VARCHAR2 DEFAULT NULL,
                              P_TCDOPERADOR  IN VARCHAR2,
                              P_CDOPERINCL   IN VARCHAR2,
                              P_CDREGIAO     IN VARCHAR2 DEFAULT NULL,
                              P_CDFORNOL     IN VARCHAR2 DEFAULT NULL,
                              P_COTA_N_DUP   OUT VARCHAR2)
    IS

        V_NRCOLEPRECO  COLETAPR.NRCOLEPRECO%TYPE;
        V_NRCOLEORIG   COLETAPR.NRCOLEPRECO%TYPE;
        V_CDOPERADOR   OPERADOR.CDOPERADOR%TYPE;
        V_IDDISMONTLIS COLETAPR.IDDISMONTLIS%TYPE;
        
        V_COUNT             INT;
        V_COUNTAUX          INT;
        
        V_PGTO_CDFORMPGTO   PRODFORN.CDFORMPGTO%TYPE;
        V_PGTO_IDTPFORPGPRF PRODFORN.IDTPFORPGPRF%TYPE;
        V_PGTO_NRPARCPGTPRF PRODFORN.NRPARCPGTPRF%TYPE;
        V_PGTO_NRDIAPGFIPRF PRODFORN.NRDIAPGFIPRF%TYPE;
        V_PGTO_IDUTDIAPGPRF PRODFORN.IDUTDIAPGPRF%TYPE;
        
        V_PGTO_IDTPFORPGTFO FORNECEDOR.IDTPFORPGTFO%TYPE;
        V_PGTO_NRPARCPGTOFO FORNECEDOR.NRPARCPGTOFO%TYPE;
        V_PGTO_NRDIAPGFIXFO FORNECEDOR.NRDIAPGFIXFO%TYPE;
        V_PGTO_IDUTDIAPGTFO FORNECEDOR.IDUTDIAPGTFO%TYPE;
        V_PGTO_IDTPDESCFORN FORNECEDOR.IDTPDESCFORN%TYPE;
        V_PGTO_VRPEDESCFORN FORNECEDOR.VRPEDESCFORN%TYPE;
        V_PGTO_IDTPFRETFORN FORNECEDOR.IDTPFRETFORN%TYPE;
        
        V_IDUTISTATCOT VARCHAR2(1);
        V_IDSITUCOLETA VARCHAR2(1);
        V_IDCOTCONCLUI VARCHAR2(1);
        
        V_IDMOTIVNDUPL LOGITEMCOLE.IDMOTIVNDUPL%TYPE;
        
        V_DSMETUSULIC VARCHAR2(50);
        
        V_PRXCOLETA   VARCHAR2(20);
        
        V_CDEMPRESA  EMPRESA.CDEMPRESA%TYPE;
        V_CDINSCESTA INSCRESTAD.CDINSCESTA%TYPE;
        
        V_CONTADOR FLOAT := 0;
        
        V_DSIP         VARCHAR2(50);
        V_DSUSUARIO    VARCHAR2(50);
        V_DSRDM        VARCHAR2(50);
        V_DSMETODO     VARCHAR2(250);
        V_DSOPERADOR   VARCHAR2(12);
        V_LISTACOTACAO VARCHAR2(32000);
        
        V_NRCOLEPRECO_AUX  COLETAPR.NRCOLEPRECO%TYPE;
        V_REC_ITEMCOLE S_RECORD_ITEMCOLE;
        V_ERROR BOOLEAN := FALSE;

        CURSOR C_COTACAO IS
            SELECT NRCOLEPRECO, COLETAPR.CDOPERADOR, IDDISMONTLIS
              FROM COLETAPR
             WHERE ((INSTR(P_CDOPERADOR, COLETAPR.CDOPERADOR) <> 0) OR
                    ((P_TCDOPERADOR = 'T') AND COLETAPR.CDOPERADOR IN ((SELECT C.CDOPERADOR
                                                                          FROM COMPROPER CO, COMPRADOR C, OPERADOR O
                                                                         WHERE CO.IDCOTCMPOPER = 'S'
                                                                           AND CO.CDCOMPRADOR  = C.CDOPERADOR
                                                                           AND CO.CDOPERADOR   = V_DSOPERADOR
                                                                           AND O.CDOPERADOR    = C.CDOPERADOR
                                                                         UNION
                                                                        SELECT C.CDOPERADOR
                                                                          FROM COMPRADOR C, OPERADOR O
                                                                         WHERE C.CDOPERADOR = O.CDOPERADOR
                                                                           AND C.CDOPERADOR = V_DSOPERADOR))))
               AND (CDFILIAL     = P_CDFILIAL)
               AND ((P_IDDUPLICA = '1' AND DTINIVALCOL >= P_DTINIVALCOL AND DTFINVALCOL <= P_DTFINVALCOL) OR
                    (P_IDDUPLICA  = '2' AND NRCOLEPRECO = P_NRCOLEDUP))
               AND EXISTS (SELECT 1
                             FROM ITEMCOLE
                            WHERE ITEMCOLE.CDFILIAL    = COLETAPR.CDFILIAL
                              AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO);
    BEGIN
        V_DSMETUSULIC := '8300_SUPSTPO_DUPLICA_COTACAO';

        WEBTUNNING(V_DSIP,
                   V_DSUSUARIO,
                   V_DSRDM,
                   V_DSMETODO,
                   V_DSOPERADOR);

        SELECT MAX(NVL(IDUTISTATCOT, 'N')), MAX(NVL(IDCOTCONCLUI, 'N'))
          INTO V_IDUTISTATCOT, V_IDCOTCONCLUI
          FROM PARASUPRI
         WHERE CDFILIAL = P_CDFILIAL;

        IF V_IDUTISTATCOT = 'S' THEN
            V_IDSITUCOLETA := 'A';
        ELSE
            V_IDSITUCOLETA := '';
        END IF;
        
        P_COTA_N_DUP := 'N';

        OPEN C_COTACAO;
        LOOP
            FETCH C_COTACAO INTO V_NRCOLEORIG, V_CDOPERADOR, V_IDDISMONTLIS;
            EXIT WHEN C_COTACAO%NOTFOUND;
        
            NOVO_CODIGO('COLETA'||P_CDFILIAL, V_PRXCOLETA);
            V_NRCOLEPRECO := SUBSTR(V_PRXCOLETA,11,10);
        
            INSERT INTO COLETAPR(
                CDFILIAL,
                NRCOLEPRECO,
                NRSEMAINIC,
                NRSEMAFINAL,
                DTINIVALCOL,
                DTFINVALCOL,
                CDOPERADOR,
                DTCOLEPREC,
                NRCOLEORIGCO,
                CDOPERINCL,
                DTINCLCOLET,
                IDDISMONTLIS,
                IDSITUCOLETA)
            VALUES(
                P_CDFILIAL,
                V_NRCOLEPRECO,
                P_NRSEMAINIC ,
                P_NRSEMAFINAL,
                P_DTNOVINIVAL,
                P_DTNOVFINVAL,
                V_CDOPERADOR,
                P_DTCOLEPREC,
                V_NRCOLEORIG,
                P_CDOPERINCL,
                SYSDATE,
                V_IDDISMONTLIS,
                V_IDSITUCOLETA);

            FOR C_REGIAO IN (SELECT CDREGIAO
                               FROM REGIAO
                              WHERE INSTR(NVL(P_CDREGIAO, REGIAO.CDREGIAO), REGIAO.CDREGIAO) <> 0
                                AND EXISTS (SELECT 1
                                              FROM ITEMCOLE
                                             WHERE ITEMCOLE.CDFILIAL = P_CDFILIAL
                                               AND ITEMCOLE.NRCOLEPRECO = V_NRCOLEORIG
                                              AND ITEMCOLE.CDREGIAO = REGIAO.CDREGIAO)
              )
            LOOP
                FOR C_ITEMCOLE IN (SELECT I.CDFILIAL, V_NRCOLEPRECO AS NRCOLEPRECO, I.CDFORNECED, I.CDREGIAO,
                                          I.CDPRODUTO, P.CDARVPROD, I.CDMARCA, I.CDTIPCOB,
                                          I.CDSEGMARCCOL, P_DTNOVINIVAL AS DTNOVINIVAL, P_DTNOVFINVAL AS DTNOVFINVAL,
                                          I.VRPRECUNIITM + ((I.VRPRECUNIITM * P_REAJUSTE) / 100) AS VRPRECUNIITM,
                                          I.VRPRECECOITM, I.VRPERDESITM, I.IDTIPFREITM, I.NRPZOENTCOL,
                                          I.CDFORMPGTO, I.IDTPFOPGTCOL, I.NRPARCPGTCOL, I.NRDIAPGFXCOL,
                                          I.IDUTDIAPGCOL, I.DSPZOPGTCONC, F.IDSITUCADA, F.CDQUALIF,
                                          F.IDFORNAUTO, F.DTVALQUALIF
                                     FROM ITEMCOLE I INNER JOIN PRODUTO    P ON P.CDPRODUTO  = I.CDPRODUTO
                                                     INNER JOIN FORNECEDOR F ON F.CDFORNECED = I.CDFORNECED
                                    WHERE I.CDFILIAL     = P_CDFILIAL
                                      AND I.NRCOLEPRECO  = V_NRCOLEORIG
                                      AND I.CDREGIAO     = C_REGIAO.CDREGIAO)
                LOOP
                    V_ERROR := FALSE;
                    
                    V_REC_ITEMCOLE.CDFILIAL        := C_ITEMCOLE.CDFILIAL;
                    V_REC_ITEMCOLE.NRCOLEPRECO     := C_ITEMCOLE.NRCOLEPRECO;
                    V_REC_ITEMCOLE.CDREGIAO        := C_ITEMCOLE.CDREGIAO;
                    V_REC_ITEMCOLE.CDFORNECED      := C_ITEMCOLE.CDFORNECED;
                    V_REC_ITEMCOLE.CDPRODUTO       := C_ITEMCOLE.CDPRODUTO;
                    V_REC_ITEMCOLE.CDMARCA         := C_ITEMCOLE.CDMARCA;
                    V_REC_ITEMCOLE.DTINIVALITM     := P_DTNOVINIVAL;
                    V_REC_ITEMCOLE.DTFINVALITM     := P_DTNOVFINVAL;
                    V_REC_ITEMCOLE.CDTIPCOB        := C_ITEMCOLE.CDTIPCOB;
                    V_REC_ITEMCOLE.CDSEGMARCCOL    := C_ITEMCOLE.CDSEGMARCCOL;
                    V_REC_ITEMCOLE.IDTIPFREITM     := C_ITEMCOLE.IDTIPFREITM;
                    V_REC_ITEMCOLE.NRPZOENTCOL     := C_ITEMCOLE.NRPZOENTCOL;
                    V_REC_ITEMCOLE.DSPZOPGTCONC    := C_ITEMCOLE.DSPZOPGTCONC;
                    V_REC_ITEMCOLE.VRPRECUNIITM    := C_ITEMCOLE.VRPRECUNIITM;
                    V_REC_ITEMCOLE.VRPRECECOITM    := C_ITEMCOLE.VRPRECECOITM;
                    V_REC_ITEMCOLE.VRPERDESITM     := C_ITEMCOLE.VRPERDESITM;
                    V_REC_ITEMCOLE.NRCOLEORIGIC    := V_NRCOLEORIG;
                    V_REC_ITEMCOLE.CDOPERINCL      := P_CDOPERINCL;
                    V_REC_ITEMCOLE.IDPRECALT       := 'N';
                    V_REC_ITEMCOLE.DTINCLITMCOL    := SYSDATE;
                    
                    IF ((V_IDUTISTATCOT = 'S') AND (V_IDCOTCONCLUI = 'S')) THEN
                        SELECT MAX(I.NRCOLEPRECO)
                          INTO V_NRCOLEPRECO_AUX
                          FROM ITEMCOLE I INNER JOIN COLETAPR C ON C.CDFILIAL    = I.CDFILIAL
                                                               AND C.NRCOLEPRECO = I.NRCOLEPRECO
                         WHERE I.CDFILIAL    = C_ITEMCOLE.CDFILIAL
                           AND I.NRCOLEPRECO <> C_ITEMCOLE.NRCOLEPRECO
                           AND I.CDMARCA     = C_ITEMCOLE.CDMARCA
                           AND I.CDREGIAO    = C_ITEMCOLE.CDREGIAO
                           AND I.CDFORNECED  = C_ITEMCOLE.CDFORNECED
                           AND I.CDPRODUTO   = C_ITEMCOLE.CDPRODUTO
                           AND C.DTINIVALCOL = C_ITEMCOLE.DTNOVINIVAL
                           AND C.DTFINVALCOL = C_ITEMCOLE.DTNOVFINVAL
                           AND NVL(C.IDSITUCOLETA, 'C') = 'C';

                        IF V_NRCOLEPRECO_AUX IS NOT NULL THEN
                            P_COTA_N_DUP := 'S';
                            IF (NVL(INSTR(V_LISTACOTACAO, C_ITEMCOLE.NRCOLEPRECO), 0) = 0) THEN
                                V_LISTACOTACAO := V_LISTACOTACAO||C_ITEMCOLE.NRCOLEPRECO||'_';
                            END IF;
                            
                            INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                               P_DSENDUSULIC   => V_DSIP,
                                               P_DSNMUSULIC    => V_DSUSUARIO,
                                               P_DSRDMUSULIC   => V_DSRDM,
                                               P_DSMETUSULIC   => V_DSMETODO,
                                               P_CDOPERLIC     => V_DSOPERADOR,
                                               P_IDOPERALIC    => 'N',
                                               P_DSMESSAGERROR => 'NAO_DUPLICA_COTACAO_CONCLUIDA');
                        END IF;
                    END IF;
            
                    IF V_NRCOLEPRECO_AUX IS NULL THEN
                        IF C_ITEMCOLE.IDSITUCADA = 'I' THEN
                            INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                               P_DSENDUSULIC   => V_DSIP,
                                               P_DSNMUSULIC    => V_DSUSUARIO,
                                               P_DSRDMUSULIC   => V_DSRDM,
                                               P_DSMETUSULIC   => V_DSMETODO,
                                               P_CDOPERLIC     => V_DSOPERADOR,
                                               P_IDOPERALIC    => 'N',
                                               P_DSMESSAGERROR => 'FORNECEDOR_INATIVO');
                        END IF;
                        
                        SELECT COUNT(1)
                          INTO V_COUNT
                          FROM REFOREG
                         WHERE REFOREG.CDREGIAO = C_ITEMCOLE.CDREGIAO
                           AND REFOREG.CDFORNECED = C_ITEMCOLE.CDFORNECED;
                           
                        IF V_COUNT <> 0 THEN
                            V_ERROR := TRUE;
                            INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                               P_DSENDUSULIC   => V_DSIP,
                                               P_DSNMUSULIC    => V_DSUSUARIO,
                                               P_DSRDMUSULIC   => V_DSRDM,
                                               P_DSMETUSULIC   => V_DSMETODO,
                                               P_CDOPERLIC     => V_DSOPERADOR,
                                               P_IDOPERALIC    => 'N',
                                               P_DSMESSAGERROR => 'FORNECEDOR_N_ATENDE_REGIAO');
                        END IF;

                        SELECT COUNT(1)
                          INTO V_COUNT
                          FROM QFOPRODFORN, PARASUPRI
                         WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                           AND QFOPRODFORN.CDPRODUTO = C_ITEMCOLE.CDPRODUTO
                           AND QFOPRODFORN.CDFORNECED = C_ITEMCOLE.CDFORNECED
                           AND ((QFOPRODFORN.IDFORNAPROV = 'N' AND QFOPRODFORN.IDFORNAUTOR = 'N') OR
                                ((QFOPRODFORN.IDFORNAPROV = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND P_DTCOLEPREC > LAST_DAY(QFOPRODFORN.DTVALPRFORN)) OR
                                                                      (PARASUPRI.IDULTIDTVALQ = 'D' AND P_DTCOLEPREC > QFOPRODFORN.DTVALPRFORN))));

                        IF V_COUNT <> 0 THEN
                            V_ERROR := TRUE;
                            INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                               P_DSENDUSULIC   => V_DSIP,
                                               P_DSNMUSULIC    => V_DSUSUARIO,
                                               P_DSRDMUSULIC   => V_DSRDM,
                                               P_DSMETUSULIC   => V_DSMETODO,
                                               P_CDOPERLIC     => V_DSOPERADOR,
                                               P_IDOPERALIC    => 'N',
                                               P_DSMESSAGERROR => 'QUALIFICACAO_PRODUTO_FORNECEDOR');
                        END IF;

                        SELECT COUNT(1)
                          INTO V_COUNT
                          FROM QFOMARPROD, PARASUPRI
                         WHERE PARASUPRI.CDFILIAL = P_CDFILIAL
                           AND QFOMARPROD.CDPRODUTO = C_ITEMCOLE.CDPRODUTO
                           AND QFOMARPROD.CDMARCA = C_ITEMCOLE.CDMARCA
                           AND ((QFOMARPROD.IDAPRMARPRO = 'N' AND QFOMARPROD.IDAUTMARPRO = 'N') OR
                                ((QFOMARPROD.IDAPRMARPRO = 'S') AND ((PARASUPRI.IDULTIDTVALQ = 'M' AND P_DTCOLEPREC > LAST_DAY(QFOMARPROD.DTVALAPROVA)) OR
                                                                     (PARASUPRI.IDULTIDTVALQ = 'D' AND P_DTCOLEPREC > QFOMARPROD.DTVALAPROVA))));

                        SELECT COUNT(1)
                          INTO V_COUNTAUX
                          FROM (SELECT QFOMARPROD.CDMARCA
                                  FROM QFOMARPROD
                                 WHERE QFOMARPROD.CDPRODUTO = C_ITEMCOLE.CDPRODUTO 
                                   AND QFOMARPROD.CDMARCA   = C_ITEMCOLE.CDMARCA
                                 UNION
                                SELECT PARASUPRI.CDMARCA
                                  FROM PARASUPRI
                                 WHERE PARASUPRI.CDFILIAL     = P_CDFILIAL 
                                   AND (PARASUPRI.IDMARSEMQUA = 'N' OR PARASUPRI.IDMARSEMQUA IS NULL));
                                   
                        IF (V_COUNT = 0) AND (V_COUNTAUX <> 0) THEN
                            V_ERROR := TRUE;
                            INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                               P_DSENDUSULIC   => V_DSIP,
                                               P_DSNMUSULIC    => V_DSUSUARIO,
                                               P_DSRDMUSULIC   => V_DSRDM,
                                               P_DSMETUSULIC   => V_DSMETODO,
                                               P_CDOPERLIC     => V_DSOPERADOR,
                                               P_IDOPERALIC    => 'N',
                                               P_DSMESSAGERROR => 'QUALIFICACAO_MARCA_PRODUTO');
                        END IF;
                        
                        SELECT COUNT(1)
                          INTO V_COUNT
                          FROM QUALIFICACAO, PARASUPRI
                         WHERE QUALIFICACAO.CDQUALIF = C_ITEMCOLE.CDQUALIF
                           AND PARASUPRI.CDFILIAL = P_CDFILIAL
                           AND C_ITEMCOLE.IDFORNAUTO = 'N'
                           AND ((QUALIFICACAO.IDPERCOTCMP = '2') OR ((PARASUPRI.IDULTIDTVALQ = 'D' AND P_DTNOVFINVAL > C_ITEMCOLE.DTVALQUALIF) OR
                                                                     (PARASUPRI.IDULTIDTVALQ = 'M' AND P_DTNOVFINVAL > LAST_DAY(C_ITEMCOLE.DTVALQUALIF))));
                                                                     
                        IF V_COUNT <> 0 THEN
                            V_ERROR := TRUE;
                            INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                               P_DSENDUSULIC   => V_DSIP,
                                               P_DSNMUSULIC    => V_DSUSUARIO,
                                               P_DSRDMUSULIC   => V_DSRDM,
                                               P_DSMETUSULIC   => V_DSMETODO,
                                               P_CDOPERLIC     => V_DSOPERADOR,
                                               P_IDOPERALIC    => 'N',
                                               P_DSMESSAGERROR => 'QUALIFICACAO_FORNECEDOR');
                        END IF;
                        
                        SELECT COUNT(1)
                          INTO V_COUNT
                          FROM PRODFORN, PRODUTO PRODUTO_PRODFORN
                         WHERE PRODFORN.CDPRODUTO = PRODUTO_PRODFORN.CDPRODUTO
                           AND PRODFORN.CDFORNECED = C_ITEMCOLE.CDFORNECED
                           AND C_ITEMCOLE.CDARVPROD LIKE PRODUTO_PRODFORN.CDARVPROD||'%';
                           
                        IF V_COUNT = 0 THEN
                            V_ERROR := TRUE;
                            INSERT_LOGITEMCOLE(P_ITEMCOLE      => V_REC_ITEMCOLE,
                                               P_DSENDUSULIC   => V_DSIP,
                                               P_DSNMUSULIC    => V_DSUSUARIO,
                                               P_DSRDMUSULIC   => V_DSRDM,
                                               P_DSMETUSULIC   => V_DSMETODO,
                                               P_CDOPERLIC     => V_DSOPERADOR,
                                               P_IDOPERALIC    => 'N',
                                               P_DSMESSAGERROR => 'PRODUTO_N_CADASTRADO_FORNECEDOR');
                        END IF;
                        
                        IF NOT V_ERROR THEN
                            INSERT INTO ITEMCOLE(
                                CDFILIAL,     NRCOLEPRECO,
                                CDFORNECED,   CDREGIAO,
                                CDPRODUTO,    CDMARCA,
                                CDTIPCOB,     CDSEGMARCCOL,
                                DTINIVALITM,  DTFINVALITM,
                                VRPRECUNIITM, VRPRECECOITM,
                                VRPERDESITM,  IDTIPFREITM,
                                NRPZOENTCOL,  DSPZOPGTCONC,
                                NRCOLEORIGIC, CDOPERINCL,
                                IDPRECALT,    DTINCLITMCOL)
                            VALUES(
                                C_ITEMCOLE.CDFILIAL,       C_ITEMCOLE.NRCOLEPRECO,
                                C_ITEMCOLE.CDFORNECED,     C_ITEMCOLE.CDREGIAO,
                                C_ITEMCOLE.CDPRODUTO,      C_ITEMCOLE.CDMARCA,
                                C_ITEMCOLE.CDTIPCOB,       C_ITEMCOLE.CDSEGMARCCOL,
                                C_ITEMCOLE.DTNOVINIVAL,    C_ITEMCOLE.DTNOVFINVAL,
                                C_ITEMCOLE.VRPRECUNIITM,   C_ITEMCOLE.VRPRECECOITM,
                                C_ITEMCOLE.VRPERDESITM,    C_ITEMCOLE.IDTIPFREITM,
                                C_ITEMCOLE.NRPZOENTCOL,    C_ITEMCOLE.DSPZOPGTCONC,
                                V_NRCOLEORIG,              P_CDOPERINCL,
                                'N',                       SYSDATE);

                            SELECT MAX(PRODFORN.CDFORMPGTO),
                                   MAX(PRODFORN.IDTPFORPGPRF),
                                   MAX(PRODFORN.NRPARCPGTPRF),
                                   MAX(PRODFORN.NRDIAPGFIPRF),
                                   MAX(PRODFORN.IDUTDIAPGPRF)
                              INTO V_PGTO_CDFORMPGTO,
                                   V_PGTO_IDTPFORPGPRF,
                                   V_PGTO_NRPARCPGTPRF,
                                   V_PGTO_NRDIAPGFIPRF,
                                   V_PGTO_IDUTDIAPGPRF
                              FROM PRODFORN, PRODUTO
                             WHERE PRODFORN.CDPRODUTO = PRODUTO.CDPRODUTO
                               AND PRODFORN.CDFORNECED = C_ITEMCOLE.CDFORNECED
                               AND PRODUTO.CDARVPROD = (SELECT MAX(PRODUTO.CDARVPROD)
                                                          FROM PRODFORN, PRODUTO
                                                         WHERE PRODFORN.CDPRODUTO   = PRODUTO.CDPRODUTO
                                                           AND PRODFORN.CDFORNECED  = C_ITEMCOLE.CDFORNECED
                                                           AND C_ITEMCOLE.CDARVPROD LIKE PRODUTO.CDARVPROD || '%');

                            IF V_PGTO_IDTPFORPGPRF IS NULL THEN
                                SELECT CDFORMPGTO, IDTPFORPGTFO, NRPARCPGTOFO, NRDIAPGFIXFO, IDUTDIAPGTFO,
                                       IDTPDESCFORN, VRPEDESCFORN, IDTPFRETFORN
                                  INTO V_PGTO_CDFORMPGTO, V_PGTO_IDTPFORPGTFO, V_PGTO_NRPARCPGTOFO, V_PGTO_NRDIAPGFIXFO, V_PGTO_IDUTDIAPGTFO,
                                       V_PGTO_IDTPDESCFORN, V_PGTO_VRPEDESCFORN, V_PGTO_IDTPFRETFORN
                                  FROM FORNECEDOR
                                 WHERE CDFORNECED = C_ITEMCOLE.CDFORNECED;

                                UPDATE ITEMCOLE 
                                   SET CDFORMPGTO   = V_PGTO_CDFORMPGTO, 
                                       IDTPFOPGTCOL = V_PGTO_IDTPFORPGTFO,
                                       NRDIAPGFXCOL = V_PGTO_NRDIAPGFIXFO,
                                       NRPARCPGTCOL = V_PGTO_NRPARCPGTOFO,
                                       IDUTDIAPGCOL = V_PGTO_IDUTDIAPGTFO
                                 WHERE CDFILIAL    = C_ITEMCOLE.CDFILIAL
                                   AND NRCOLEPRECO = C_ITEMCOLE.NRCOLEPRECO
                                   AND CDPRODUTO   = C_ITEMCOLE.CDPRODUTO
                                   AND CDMARCA     = C_ITEMCOLE.CDMARCA
                                   AND CDFORNECED  = C_ITEMCOLE.CDFORNECED
                                   AND CDREGIAO    = C_ITEMCOLE.CDREGIAO;
                        
                                IF V_PGTO_IDTPFORPGTFO = 'V' THEN
                                    INSERT INTO PZOPGTITMCOL(
                                        CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
                                        CDMARCA, CDREGIAO, NRDIASPGTCOL, VRPERCPGTCOL)
                                    SELECT C_ITEMCOLE.CDFILIAL, C_ITEMCOLE.NRCOLEPRECO, C_ITEMCOLE.CDFORNECED, C_ITEMCOLE.CDPRODUTO,
                                           C_ITEMCOLE.CDMARCA, C_ITEMCOLE.CDREGIAO, PRAZOPGTFORN.NRDIASPGTOFO, PRAZOPGTFORN.VRPERCPGTOFO
                                      FROM PRAZOPGTFORN
                                     WHERE PRAZOPGTFORN.CDFORNECED = C_ITEMCOLE.CDFORNECED;
                                END IF;
                            ELSE
                                UPDATE ITEMCOLE
                                   SET CDFORMPGTO   = V_PGTO_CDFORMPGTO,
                                       IDTPFOPGTCOL = V_PGTO_IDTPFORPGPRF,
                                       NRDIAPGFXCOL = V_PGTO_NRDIAPGFIPRF,
                                       NRPARCPGTCOL = V_PGTO_NRPARCPGTPRF,
                                       IDUTDIAPGCOL = V_PGTO_IDUTDIAPGPRF
                                 WHERE CDFILIAL    = C_ITEMCOLE.CDFILIAL
                                   AND NRCOLEPRECO = C_ITEMCOLE.NRCOLEPRECO
                                   AND CDPRODUTO   = C_ITEMCOLE.CDPRODUTO
                                   AND CDMARCA     = C_ITEMCOLE.CDMARCA
                                   AND CDFORNECED  = C_ITEMCOLE.CDFORNECED
                                   AND CDREGIAO    = C_ITEMCOLE.CDREGIAO;
                            
                                IF V_PGTO_IDTPFORPGPRF = 'V' THEN
                                    INSERT INTO PZOPGTITMCOL(
                                        CDFILIAL, NRCOLEPRECO, CDFORNECED, CDPRODUTO,
                                        CDMARCA, CDREGIAO, NRDIASPGTCOL, VRPERCPGTCOL)
                                    SELECT C_ITEMCOLE.CDFILIAL, C_ITEMCOLE.NRCOLEPRECO, C_ITEMCOLE.CDFORNECED, C_ITEMCOLE.CDPRODUTO,
                                           C_ITEMCOLE.CDMARCA, C_ITEMCOLE.CDREGIAO, PZOPGTPRFO.NRDIASPGPRFO, PZOPGTPRFO.VRPERCPGPRFO
                                      FROM PZOPGTPRFO, PRODUTO
                                     WHERE PZOPGTPRFO.CDPRODUTO  = PRODUTO.CDPRODUTO
                                       AND PZOPGTPRFO.CDFORNECED = C_ITEMCOLE.CDFORNECED
                                       AND C_ITEMCOLE.CDARVPROD LIKE PRODUTO.CDARVPROD || '%';
                                END IF;
                            END IF;

                            SELECT SUBSTR(EMITENTE(P_CDFILIAL, C_ITEMCOLE.CDPRODUTO, C_ITEMCOLE.CDFORNECED), 3, 2) AS CDEMPRESA
                              INTO V_CDEMPRESA
                              FROM PARAMGERAL;
                            
                            SELECT MAX(EMPRESA.CDEMPRESA), MIN(INSCRESTAD.CDINSCESTA)
                              INTO V_CDEMPRESA, V_CDINSCESTA
                              FROM EMPRESA, INSCRESTAD
                             WHERE EMPRESA.CDEMPRESA = V_CDEMPRESA
                               AND EMPRESA.CDEMPRESA = INSCRESTAD.CDEMPRESA;
                            
                            IMPOSTO_ITEMCOL(V_CDEMPRESA,        V_CDINSCESTA,          C_ITEMCOLE.CDFORNECED, P_CDFILIAL,
                                            V_NRCOLEPRECO,      C_ITEMCOLE.CDFORNECED, C_ITEMCOLE.CDREGIAO,   C_ITEMCOLE.CDPRODUTO,
                                            C_ITEMCOLE.CDMARCA, P_DTCOLEPREC);
                            
                            DELETE ITEMCOLE
                             WHERE ITEMCOLE.NRCOLEPRECO <> C_ITEMCOLE.NRCOLEPRECO
                               AND ITEMCOLE.CDFILIAL    =  C_ITEMCOLE.CDFILIAL
                               AND ITEMCOLE.CDPRODUTO   =  C_ITEMCOLE.CDPRODUTO
                               AND ITEMCOLE.CDMARCA     =  C_ITEMCOLE.CDMARCA
                               AND ITEMCOLE.CDFORNECED  =  C_ITEMCOLE.CDFORNECED
                               AND ITEMCOLE.CDREGIAO    =  C_ITEMCOLE.CDREGIAO
                               AND ITEMCOLE.DTINIVALITM =  C_ITEMCOLE.DTNOVINIVAL
                               AND ITEMCOLE.DTFINVALITM =  C_ITEMCOLE.DTNOVFINVAL;
                        ELSE
                            P_COTA_N_DUP := 'S';
                            IF (NVL(INSTR(V_LISTACOTACAO, C_ITEMCOLE.NRCOLEPRECO), 0) = 0) THEN
                                V_LISTACOTACAO := V_LISTACOTACAO||C_ITEMCOLE.NRCOLEPRECO||'_';
                            END IF;
                        END IF;
                        
                        UPDATE ITEMCOLE
                           SET IDTPFOPGTCOL  = IDTPFOPGTCOL
                         WHERE CDFILIAL    = C_ITEMCOLE.CDFILIAL
                           AND NRCOLEPRECO = C_ITEMCOLE.NRCOLEPRECO
                           AND CDFORNECED  = C_ITEMCOLE.CDFORNECED
                           AND CDREGIAO    = C_ITEMCOLE.CDREGIAO
                           AND CDPRODUTO   = C_ITEMCOLE.CDPRODUTO
                           AND CDMARCA     = C_ITEMCOLE.CDMARCA;
                    END IF;
                END LOOP;
            END LOOP;

            IF P_CDFORNOL IS NOT NULL THEN
                SUP_COTACAO.COTACAO_OPL(P_CDFILIAL    => P_CDFILIAL,
                                        P_NRCOLEORIG  => V_NRCOLEORIG,
                                        P_NRCOLEPRECO => V_NRCOLEPRECO,
                                        P_FORNOL      => P_CDFORNOL,
                                        P_REAJUSTE    => P_REAJUSTE,
                                        P_DTNOVINIVAL => P_DTNOVINIVAL,
                                        P_DTNOVFINVAL => P_DTNOVFINVAL,
                                        P_CDOPERINCL  => P_CDOPERINCL);
            END IF;

            COMMIT;
        END LOOP;
        CLOSE C_COTACAO;

        IF P_COTA_N_DUP = 'S' THEN
            P_COTA_N_DUP := 'S_'||V_LISTACOTACAO;
        END IF;

        FOR C_LIMPEZA IN (SELECT CDFILIAL, NRCOLEPRECO
                            FROM COLETAPR
                           WHERE DTINIVALCOL >= P_DTINIVALCOL
                             AND DTFINVALCOL <= P_DTFINVALCOL
                             AND NOT EXISTS (SELECT 1
                                               FROM ITEMCOLE
                                              WHERE ITEMCOLE.CDFILIAL    = COLETAPR.CDFILIAL
                                                AND ITEMCOLE.NRCOLEPRECO = COLETAPR.NRCOLEPRECO))
        LOOP
            DELETE FROM COLETAPR
             WHERE CDFILIAL    = C_LIMPEZA.CDFILIAL
               AND NRCOLEPRECO = C_LIMPEZA.NRCOLEPRECO;

            V_CONTADOR := V_CONTADOR + 1;
            
            IF V_CONTADOR >= 500 THEN
                V_CONTADOR := 0;
                COMMIT;
            END IF;
        END LOOP;

        COMMIT;      
    END DUPLICA_COTACAO;
END SUP_COTACAO;
/